@@ -43,7 +43,6 @@
 #include <QTimer>
 #include <QToolButton>
 #include <QWheelEvent>
-#include <QLocale>
 
 using namespace EventViews;
 
@@ -75,8 +74,7 @@ protected:
     /* reimplemented from KCalCore::Calendar::CalendarObserver */
     void calendarIncidenceAdded(const KCalCore::Incidence::Ptr &incidence) override;
     void calendarIncidenceChanged(const KCalCore::Incidence::Ptr &incidence) override;
-    void calendarIncidenceDeleted(const KCalCore::Incidence::Ptr &incidence,
-                                  const KCalCore::Calendar *calendar) override;
+    void calendarIncidenceDeleted(const KCalCore::Incidence::Ptr &incidence, const KCalCore::Calendar *calendar) override;
 private:
     //quiet --overloaded-virtual warning
     using KCalCore::Calendar::CalendarObserver::calendarIncidenceDeleted;
@@ -148,8 +146,7 @@ void MonthViewPrivate::calendarIncidenceChanged(const KCalCore::Incidence::Ptr &
     triggerDelayedReload(MonthView::IncidencesEdited);
 }
 
-void MonthViewPrivate::calendarIncidenceDeleted(const KCalCore::Incidence::Ptr &incidence,
-                                                const KCalCore::Calendar *calendar)
+void MonthViewPrivate::calendarIncidenceDeleted(const KCalCore::Incidence::Ptr &incidence, const KCalCore::Calendar *calendar)
 {
     Q_UNUSED(calendar);
     Q_ASSERT(!incidence->uid().isEmpty());
@@ -315,8 +312,7 @@ QDateTime MonthView::selectionEnd() const
     return selectionStart();
 }
 
-void MonthView::setDateRange(const QDateTime &start, const QDateTime &end,
-                             const QDate &preferredMonth)
+void MonthView::setDateRange(const QDateTime &start, const QDateTime &end, const QDate &preferredMonth)
 {
     EventView::setDateRange(start, end, preferredMonth);
     setChanges(changes() | DatesChanged);
@@ -448,12 +444,11 @@ void MonthView::showDates(const QDate &start, const QDate &end, const QDate &pre
     d->triggerDelayedReload(DatesChanged);
 }
 
-QPair<QDateTime, QDateTime> MonthView::actualDateRange(const QDateTime &start, const QDateTime &,
-                                                       const QDate &preferredMonth) const
+QPair<QDateTime, QDateTime> MonthView::actualDateRange(const QDateTime &start, const QDateTime &, const QDate &preferredMonth) const
 {
     QDateTime dayOne = preferredMonth.isValid() ? QDateTime(preferredMonth) : start;
     dayOne.setDate(QDate(dayOne.date().year(), dayOne.date().month(), 1));
-    const int weekdayCol = (dayOne.date().dayOfWeek() + 7 - QLocale().firstDayOfWeek()) % 7;
+    const int weekdayCol = (dayOne.date().dayOfWeek() + 7 - preferences()->firstDayOfWeek()) % 7;
     QDateTime actualStart = dayOne.addDays(-weekdayCol);
     actualStart.setTime(QTime(0, 0, 0, 0));
     QDateTime actualEnd = actualStart.addDays(6 * 7 - 1);
@@ -562,8 +557,8 @@ void MonthView::reloadIncidences()
             if (!holidays.isEmpty()) {
                 MonthItem *holidayItem
                     = new HolidayMonthItem(
-                    d->scene, date,
-                    holidays.join(i18nc("@item:intext delimiter for joining holiday names", ",")));
+                          d->scene, date,
+                          holidays.join(i18nc("@item:intext delimiter for joining holiday names", ",")));
                 d->scene->mManagerList << holidayItem;
             }
         }
